// src/components/RoadmapDetail.jsx
import React, { useState, useEffect } from 'react';
import { useParams, Link } from 'react-router-dom';
import roadmaps from '../roadmaps.json';

const RoadmapDetail = () => {
  const { id } = useParams();
  const [roadmap, setRoadmap] = useState(null);
  const [activeStep, setActiveStep] = useState(0);

  useEffect(() => {
    // Find the roadmap with the matching id
    const foundRoadmap = roadmaps.find(r => r.id === id);
    if (foundRoadmap) {
      setRoadmap(foundRoadmap);
    }
  }, [id]);

  if (!roadmap) {
    return (
      <div className="container mx-auto px-6 py-16 text-center">
        <h2 className="text-3xl font-bold mb-4">Roadmap Not Found</h2>
        <p className="text-gray-300 mb-8">We couldn't find the roadmap you're looking for.</p>
        <Link 
          to="/roadmap" 
          className="px-6 py-3 bg-primary-600 hover:bg-primary-700 text-white rounded-lg transition-colors"
        >
          View All Roadmaps
        </Link>
      </div>
    );
  }

  // Mock data for steps (this would come from the roadmap data in a real implementation)
  const steps = [
    {
      title: "Getting Started",
      description: "Begin your journey by understanding the fundamentals and setting up your learning environment.",
      content: `
        <p>Welcome to your tech journey! This first phase is all about building a solid foundation. You'll get familiar with key concepts, tools, and start building habits that will serve you throughout your career.</p>
        <h4>Key Objectives:</h4>
        <ul>
          <li>Understand the field and career opportunities</li>
          <li>Set up your development environment</li>
          <li>Learn the fundamental concepts</li>
          <li>Build your first small projects</li>
        </ul>
      `,
      resources: [
        { title: "Free Code Camp", url: "https://www.freecodecamp.org/" },
        { title: "The Odin Project", url: "https://www.theodinproject.com/" },
        { title: "MDN Web Docs", url: "https://developer.mozilla.org/" }
      ]
    },
    {
      title: "Building Skills",
      description: "Develop core technical skills and start working on meaningful projects.",
      content: `
        <p>Now that you have the basics down, it's time to deepen your knowledge and start applying what you've learned to more complex problems and projects.</p>
        <h4>Key Objectives:</h4>
        <ul>
          <li>Master core programming concepts</li>
          <li>Learn industry-standard tools and frameworks</li>
          <li>Build a portfolio of projects</li>
          <li>Practice problem-solving skills</li>
        </ul>
      `,
      resources: [
        { title: "LeetCode", url: "https://leetcode.com/" },
        { title: "GitHub Learning Lab", url: "https://lab.github.com/" },
        { title: "Codecademy", url: "https://www.codecademy.com/" }
      ]
    },
    {
      title: "Professional Development",
      description: "Prepare for the job market and develop professional skills.",
      content: `
        <p>Technical skills are just one part of a successful tech career. In this phase, you'll focus on the professional aspects of working in tech and prepare for your job search.</p>
        <h4>Key Objectives:</h4>
        <ul>
          <li>Create a professional resume and online presence</li>
          <li>Develop interview skills (technical and behavioral)</li>
          <li>Build your network and find mentors</li>
          <li>Learn about industry practices and workflows</li>
        </ul>
      `,
      resources: [
        { title: "Tech Interview Handbook", url: "https://www.techinterviewhandbook.org/" },
        { title: "LinkedIn Learning", url: "https://www.linkedin.com/learning/" },
        { title: "AngelList", url: "https://angel.co/jobs" }
      ]
    },
    {
      title: "Landing Your First Role",
      description: "Strategies for job searching and excelling in your first position.",
      content: `
        <p>This is where all your hard work comes together. You'll apply for jobs, go through interviews, and start your professional journey in tech.</p>
        <h4>Key Objectives:</h4>
        <ul>
          <li>Develop an effective job search strategy</li>
          <li>Prepare for technical and behavioral interviews</li>
          <li>Evaluate job offers and negotiate compensation</li>
          <li>Plan for success in your first 90 days</li>
        </ul>
      `,
      resources: [
        { title: "Hired", url: "https://hired.com/" },
        { title: "Glassdoor", url: "https://www.glassdoor.com/" },
        { title: "Blind", url: "https://www.teamblind.com/" }
      ]
    }
  ];

  return (
    <div className="container mx-auto px-6 py-16">
      {/* Roadmap Header */}
      <div className="mb-16 text-center">
        <Link to="/roadmap" className="text-primary-400 hover:text-primary-300 transition-colors inline-flex items-center mb-6">
          <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2" viewBox="0 0 20 20" fill="currentColor">
            <path fillRule="evenodd" d="M9.707 16.707a1 1 0 01-1.414 0l-6-6a1 1 0 010-1.414l6-6a1 1 0 011.414 1.414L5.414 9H17a1 1 0 110 2H5.414l4.293 4.293a1 1 0 010 1.414z" clipRule="evenodd" />
          </svg>
          Back to Roadmaps
        </Link>
        <h1 className="text-4xl md:text-5xl font-bold mb-4">{roadmap.title}</h1>
        <p className="text-xl text-gray-300 max-w-3xl mx-auto">{roadmap.description}</p>
      </div>

      {/* Progress Indicator */}
      <div className="mb-12">
        <div className="relative">
          <div className="absolute inset-0 flex items-center">
            <div className="w-full border-t-2 border-dark-600"></div>
          </div>
          <div className="relative flex justify-between">
            {steps.map((step, index) => (
              <button
                key={index}
                onClick={() => setActiveStep(index)}
                className={`flex items-center justify-center w-12 h-12 rounded-full text-lg font-bold ${
                  index === activeStep
                    ? 'bg-primary-500 text-white shadow-lg'
                    : index < activeStep
                    ? 'bg-primary-800 text-primary-200'
                    : 'bg-dark-600 text-gray-400'
                } transition-all duration-300`}
              >
                {index + 1}
              </button>
            ))}
          </div>
        </div>
        <div className="mt-4 flex justify-between">
          {steps.map((step, index) => (
            <div key={index} className={`text-center w-1/4 px-2 ${
              index === activeStep ? 'text-white' : 'text-gray-400'
            }`}>
              <h4 className="font-medium text-sm md:text-base truncate">{step.title}</h4>
            </div>
          ))}
        </div>
      </div>

      {/* Active Step Content */}
      <div className="bg-dark-800 rounded-xl shadow-lg overflow-hidden">
        <div className="p-1 bg-gradient-to-r from-primary-500 to-secondary-500">
          <div className="bg-dark-800 p-8">
            <h2 className="text-3xl font-bold mb-2">{steps[activeStep].title}</h2>
            <p className="text-xl text-gray-300 mb-6">{steps[activeStep].description}</p>
            
            <div className="prose prose-invert max-w-none mb-8" dangerouslySetInnerHTML={{ __html: steps[activeStep].content }}></div>
            
            <div className="bg-dark-700 p-6 rounded-lg">
              <h3 className="text-xl font-bold mb-4">Recommended Resources</h3>
              <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
                {steps[activeStep].resources.map((resource, index) => (
                  <a 
                    key={index} 
                    href={resource.url} 
                    target="_blank" 
                    rel="noopener noreferrer"
                    className="bg-dark-600 hover:bg-dark-500 p-4 rounded-lg transition-colors flex items-center"
                  >
                    <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2 text-primary-400" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M10 6H6a2 2 0 00-2 2v10a2 2 0 002 2h10a2 2 0 002-2v-4M14 4h6m0 0v6m0-6L10 14" />
                    </svg>
                    <span>{resource.title}</span>
                  </a>
                ))}
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Navigation Buttons */}
      <div className="mt-8 flex justify-between">
        <button 
          onClick={() => setActiveStep(Math.max(0, activeStep - 1))}
          disabled={activeStep === 0}
          className={`flex items-center px-6 py-3 rounded-lg transition-colors ${
            activeStep === 0
              ? 'bg-dark-700 text-gray-500 cursor-not-allowed'
              : 'bg-dark-700 hover:bg-dark-600 text-white'
          }`}
        >
          <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 19l-7-7 7-7" />
          </svg>
          Previous Step
        </button>
        
        <button 
          onClick={() => setActiveStep(Math.min(steps.length - 1, activeStep + 1))}
          disabled={activeStep === steps.length - 1}
          className={`flex items-center px-6 py-3 rounded-lg transition-colors ${
            activeStep === steps.length - 1
              ? 'bg-dark-700 text-gray-500 cursor-not-allowed'
              : 'bg-primary-600 hover:bg-primary-700 text-white'
          }`}
        >
          Next Step
          <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 ml-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
          </svg>
        </button>
      </div>

      {/* Community Support Section */}
      <div className="mt-16 bg-dark-700 rounded-xl p-8 text-center">
        <h3 className="text-2xl font-bold mb-4">Need Support?</h3>
        <p className="text-gray-300 mb-6">
          Join our community to connect with mentors and peers who are on similar journeys.
          Get answers to your questions and share your progress.
        </p>
        <button className="px-6 py-3 bg-primary-600 hover:bg-primary-700 text-white rounded-lg transition-colors">
          Join Our Community
        </button>
      </div>
    </div>
  );
};

export default RoadmapDetail;